pub struct OneshotKey(/* private fields */);Trait Implementations
Sourceimpl Clone for OneshotKey
impl Clone for OneshotKey
Sourcefn clone(&self) -> OneshotKey
fn clone(&self) -> OneshotKey
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OneshotKey
impl Debug for OneshotKey
Sourceimpl Default for OneshotKey
impl Default for OneshotKey
Sourcefn default() -> OneshotKey
fn default() -> OneshotKey
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for OneshotKey
impl<'de> Deserialize<'de> for OneshotKey
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<KeyData> for OneshotKey
impl From<KeyData> for OneshotKey
Sourceimpl Hash for OneshotKey
impl Hash for OneshotKey
Sourceimpl Key for OneshotKey
impl Key for OneshotKey
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for OneshotKey
impl Ord for OneshotKey
Sourcefn cmp(&self, other: &OneshotKey) -> Ordering
fn cmp(&self, other: &OneshotKey) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for OneshotKey
impl PartialEq for OneshotKey
Sourceimpl PartialOrd for OneshotKey
impl PartialOrd for OneshotKey
Sourceimpl Serialize for OneshotKey
impl Serialize for OneshotKey
impl Copy for OneshotKey
impl Eq for OneshotKey
impl StructuralPartialEq for OneshotKey